@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-7 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 2000-2007,2012 Brendan Cully <brendan@kublai.com>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -26,24 +26,24 @@
 /* account types */
 enum
 {
-  M_ACCT_TYPE_NONE = 0,
-  M_ACCT_TYPE_IMAP,
-  M_ACCT_TYPE_POP,
-  M_ACCT_TYPE_SMTP
+  MUTT_ACCT_TYPE_NONE = 0,
+  MUTT_ACCT_TYPE_IMAP,
+  MUTT_ACCT_TYPE_POP,
+  MUTT_ACCT_TYPE_SMTP
 };
 
 /* account flags */
-#define M_ACCT_PORT  (1<<0)
-#define M_ACCT_USER  (1<<1)
-#define M_ACCT_LOGIN (1<<2)
-#define M_ACCT_PASS  (1<<3)
-#define M_ACCT_SSL   (1<<4)
+#define MUTT_ACCT_PORT  (1<<0)
+#define MUTT_ACCT_USER  (1<<1)
+#define MUTT_ACCT_LOGIN (1<<2)
+#define MUTT_ACCT_PASS  (1<<3)
+#define MUTT_ACCT_SSL   (1<<4)
 
 typedef struct
 {
   char user[64];
   char login[64];
-  char pass[64];
+  char pass[128];
   char host[128];
   unsigned short port;
   unsigned char type;
