@@ -256,7 +256,7 @@ void mutt_create_alias (ENVELOPE *cur, ADDRESS *iadr)
   mutt_check_alias_name (tmp, buf, sizeof (buf));
   
 retry_name:
-  /* add a new alias */
+  /* L10N: prompt to add a new alias */
   if (mutt_get_field (_("Alias as: "), buf, sizeof (buf), 0) != 0 || !buf[0])
     return;
 
@@ -269,9 +269,9 @@ retry_name:
   
   if (mutt_check_alias_name (buf, fixed, sizeof (fixed)))
   {
-    switch (mutt_yesorno (_("Warning: This alias name may not work.  Fix it?"), M_YES))
+    switch (mutt_yesorno (_("Warning: This alias name may not work.  Fix it?"), MUTT_YES))
     {
-      case M_YES:
+      case MUTT_YES:
       	strfcpy (buf, fixed, sizeof (buf));
 	goto retry_name;
       case -1: 
@@ -290,7 +290,7 @@ retry_name:
   else
     buf[0] = 0;
 
-  mutt_addrlist_to_idna (adr, NULL);
+  mutt_addrlist_to_intl (adr, NULL);
   
   do
   {
@@ -302,7 +302,7 @@ retry_name:
     
     if((new->addr = rfc822_parse_adrlist (new->addr, buf)) == NULL)
       BEEP ();
-    if (mutt_addrlist_to_idna (new->addr, &err))
+    if (mutt_addrlist_to_intl (new->addr, &err))
     {
       mutt_error (_("Error: '%s' is a bad IDN."), err);
       mutt_sleep (2);
@@ -326,7 +326,7 @@ retry_name:
   buf[0] = 0;
   rfc822_write_address (buf, sizeof (buf), new->addr, 1);
   snprintf (prompt, sizeof (prompt), _("[%s = %s] Accept?"), new->name, buf);
-  if (mutt_yesorno (prompt, M_YES) != M_YES)
+  if (mutt_yesorno (prompt, MUTT_YES) != MUTT_YES)
   {
     mutt_free_alias (&new);
     return;
@@ -344,7 +344,7 @@ retry_name:
     Aliases = new;
 
   strfcpy (buf, NONULL (AliasFile), sizeof (buf));
-  if (mutt_get_field (_("Save to file: "), buf, sizeof (buf), M_FILE) != 0)
+  if (mutt_get_field (_("Save to file: "), buf, sizeof (buf), MUTT_FILE) != 0)
     return;
   mutt_expand_path (buf, sizeof (buf));
   if ((rc = fopen (buf, "a+")))
@@ -423,6 +423,8 @@ int mutt_check_alias_name (const char *s, char *dest, size_t destlen)
     {
       if (dry)
 	return -1;
+      if (l == (size_t)(-1))
+        memset (&mb, 0, sizeof (mbstate_t));
       *dest++ = '_';
       rv = -1;
     }
