@@ -146,7 +146,7 @@ folder_format_str (char *dest, size_t destlen, size_t col, int cols, char op, co
 		   unsigned long data, format_flag flags)
 {
   char fn[SHORT_STRING], tmp[SHORT_STRING], permission[11];
-  char date[16], *t_fmt;
+  char date[SHORT_STRING], *t_fmt;
   time_t tnow;
   FOLDER *folder = (FOLDER *) data;
   struct passwd *pw;
