@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000,2002,2007 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1996-2000,2002,2007,2010,2012 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2004 g10 Code GmbH
  * 
  *     This program is free software; you can redistribute it and/or modify
@@ -52,7 +52,7 @@ static const char* There_are_no_attachments = N_("There are no attachments.");
 
 enum
 {
-  HDR_FROM  = 1,
+  HDR_FROM  = 0,
   HDR_TO,
   HDR_CC,
   HDR_BCC,
@@ -72,7 +72,7 @@ enum
 
 #define HDR_XOFFSET 10
 #define TITLE_FMT "%10s" /* Used for Prompts, which are ASCII */
-#define W (COLS - HDR_XOFFSET)
+#define W (MuttIndexWindow->cols - HDR_XOFFSET)
 
 static const char * const Prompts[] =
 {
@@ -99,9 +99,9 @@ static const struct mapping_t ComposeHelp[] = {
 
 static void snd_entry (char *b, size_t blen, MUTTMENU *menu, int num)
 {
-    mutt_FormatString (b, blen, 0, NONULL (AttachFormat), mutt_attach_fmt,
+  mutt_FormatString (b, blen, 0, MuttIndexWindow->cols, NONULL (AttachFormat), mutt_attach_fmt,
 	    (unsigned long)(((ATTACHPTR **) menu->data)[num]),
-	    M_FORMAT_STAT_FILE | M_FORMAT_ARROWCURSOR);
+	    MUTT_FORMAT_STAT_FILE | MUTT_FORMAT_ARROWCURSOR);
 }
 
 
@@ -110,7 +110,7 @@ static void snd_entry (char *b, size_t blen, MUTTMENU *menu, int num)
 
 static void redraw_crypt_lines (HEADER *msg)
 {
-  mvaddstr (HDR_CRYPT, 0, "Security: ");
+  mutt_window_mvprintw (MuttIndexWindow, HDR_CRYPT, 0, TITLE_FMT, "Security: ");
 
   if ((WithCrypto & (APPLICATION_PGP | APPLICATION_SMIME)) == 0)
   {
@@ -144,17 +144,17 @@ static void redraw_crypt_lines (HEADER *msg)
   if (option (OPTCRYPTOPPORTUNISTICENCRYPT) && (msg->security & OPPENCRYPT))
       addstr (_(" (OppEnc mode)"));
 
-  clrtoeol ();
-  move (HDR_CRYPTINFO, 0);
-  clrtoeol ();
+  mutt_window_clrtoeol (MuttIndexWindow);
+  mutt_window_move (MuttIndexWindow, HDR_CRYPTINFO, 0);
+  mutt_window_clrtoeol (MuttIndexWindow);
 
   if ((WithCrypto & APPLICATION_PGP)
       && (msg->security & APPLICATION_PGP) && (msg->security & SIGN))
-    printw ("%s%s", _(" sign as: "), PgpSignAs ? PgpSignAs : _("<default>"));
+    printw (TITLE_FMT "%s", _("sign as: "), PgpSignAs ? PgpSignAs : _("<default>"));
 
   if ((WithCrypto & APPLICATION_SMIME)
       && (msg->security & APPLICATION_SMIME) && (msg->security & SIGN)) {
-      printw ("%s%s", _(" sign as: "), SmimeDefaultKey ? SmimeDefaultKey : _("<default>"));
+      printw (TITLE_FMT "%s", _("sign as: "), SmimeDefaultKey ? SmimeDefaultKey : _("<default>"));
   }
 
   if ((WithCrypto & APPLICATION_SMIME)
@@ -162,7 +162,7 @@ static void redraw_crypt_lines (HEADER *msg)
       && (msg->security & ENCRYPT)
       && SmimeCryptAlg
       && *SmimeCryptAlg) {
-      mvprintw (HDR_CRYPTINFO, 40, "%s%s", _("Encrypt with: "),
+    mutt_window_mvprintw (MuttIndexWindow, HDR_CRYPTINFO, 40, "%s%s", _("Encrypt with: "),
 		NONULL(SmimeCryptAlg));
   }
 }
@@ -175,12 +175,13 @@ static void redraw_mix_line (LIST *chain)
   int c;
   char *t;
 
-  mvaddstr (HDR_MIX, 0,     "     Mix: ");
+  /* L10N: "Mix" refers to the MixMaster chain for anonymous email */
+  mutt_window_mvprintw (MuttIndexWindow, HDR_MIX, 0, TITLE_FMT, _("Mix: "));
 
   if (!chain)
   {
     addstr ("<no chain defined>");
-    clrtoeol ();
+    mutt_window_clrtoeol (MuttIndexWindow);
     return;
   }
   
@@ -190,7 +191,7 @@ static void redraw_mix_line (LIST *chain)
     if (t && t[0] == '0' && t[1] == '\0')
       t = "<random>";
     
-    if (c + mutt_strlen (t) + 2 >= COLS)
+    if (c + mutt_strlen (t) + 2 >= MuttIndexWindow->cols)
       break;
 
     addstr (NONULL(t));
@@ -226,7 +227,7 @@ check_attachments(ATTACHPTR **idx, short idxlen)
       snprintf(msg, sizeof(msg), _("%s [#%d] modified. Update encoding?"),
 	       pretty, i+1);
       
-      if((r = mutt_yesorno(msg, M_YES)) == M_YES)
+      if((r = mutt_yesorno(msg, MUTT_YES)) == MUTT_YES)
 	mutt_update_encoding(idx[i]->content);
       else if(r == -1)
 	return -1;
@@ -242,7 +243,7 @@ static void draw_envelope_addr (int line, ADDRESS *addr)
 
   buf[0] = 0;
   rfc822_write_address (buf, sizeof (buf), addr, 1);
-  mvprintw (line, 0, TITLE_FMT, Prompts[line - 1]);
+  mutt_window_mvprintw (MuttIndexWindow, line, 0, TITLE_FMT, Prompts[line]);
   mutt_paddstr (W, buf);
 }
 
@@ -252,10 +253,10 @@ static void draw_envelope (HEADER *msg, char *fcc)
   draw_envelope_addr (HDR_TO, msg->env->to);
   draw_envelope_addr (HDR_CC, msg->env->cc);
   draw_envelope_addr (HDR_BCC, msg->env->bcc);
-  mvprintw (HDR_SUBJECT, 0, TITLE_FMT, Prompts[HDR_SUBJECT - 1]);
+  mutt_window_mvprintw (MuttIndexWindow, HDR_SUBJECT, 0, TITLE_FMT, Prompts[HDR_SUBJECT]);
   mutt_paddstr (W, NONULL (msg->env->subject));
   draw_envelope_addr (HDR_REPLYTO, msg->env->reply_to);
-  mvprintw (HDR_FCC, 0, TITLE_FMT, Prompts[HDR_FCC - 1]);
+  mutt_window_mvprintw (MuttIndexWindow, HDR_FCC, 0, TITLE_FMT, Prompts[HDR_FCC]);
   mutt_paddstr (W, fcc);
 
   if (WithCrypto)
@@ -266,8 +267,8 @@ static void draw_envelope (HEADER *msg, char *fcc)
 #endif
 
   SETCOLOR (MT_COLOR_STATUS);
-  mvaddstr (HDR_ATTACH - 1, 0, _("-- Attachments"));
-  clrtoeol ();
+  mutt_window_mvaddstr (MuttIndexWindow, HDR_ATTACH - 1, 0, _("-- Attachments"));
+  mutt_window_clrtoeol (MuttIndexWindow);
 
   NORMAL_COLOR;
 }
@@ -279,7 +280,7 @@ static int edit_address_list (int line, ADDRESS **addr)
   
   mutt_addrlist_to_local (*addr);
   rfc822_write_address (buf, sizeof (buf), *addr, 0);
-  if (mutt_get_field (Prompts[line - 1], buf, sizeof (buf), M_ALIAS) == 0)
+  if (mutt_get_field (Prompts[line], buf, sizeof (buf), MUTT_ALIAS) == 0)
   {
     rfc822_free_address (addr);
     *addr = mutt_parse_adrlist (*addr, buf);
@@ -292,7 +293,7 @@ static int edit_address_list (int line, ADDRESS **addr)
     return (REDRAW_FULL);
   }
 
-  if (mutt_addrlist_to_idna (*addr, &err) != 0)
+  if (mutt_addrlist_to_intl (*addr, &err) != 0)
   {
     mutt_error (_("Warning: '%s' is a bad IDN."), err);
     mutt_refresh();
@@ -302,7 +303,7 @@ static int edit_address_list (int line, ADDRESS **addr)
   /* redraw the expanded list so the user can see the result */
   buf[0] = 0;
   rfc822_write_address (buf, sizeof (buf), *addr, 1);
-  move (line, HDR_XOFFSET);
+  mutt_window_move (MuttIndexWindow, line, HDR_XOFFSET);
   mutt_paddstr (W, buf);
   
   return 0;
@@ -338,6 +339,7 @@ static int delete_attachment (MUTTMENU *menu, short *idxlen, int x)
   FREE (&idx[x]);
   for (; x < *idxlen - 1; x++)
     idx[x] = idx[x+1];
+  idx[*idxlen - 1] = NULL;
   menu->max = --(*idxlen);
   
   return (0);
@@ -401,7 +403,7 @@ static unsigned long cum_attachs_size (MUTTMENU *menu)
 }
 
 /* prototype for use below */
-static void compose_status_line (char *buf, size_t buflen, size_t col, MUTTMENU *menu, 
+static void compose_status_line (char *buf, size_t buflen, size_t col, int cols, MUTTMENU *menu, 
       const char *p);
 
 /*
@@ -417,13 +419,13 @@ static void compose_status_line (char *buf, size_t buflen, size_t col, MUTTMENU
  */
 
 static const char *
-compose_format_str (char *buf, size_t buflen, size_t col, char op, const char *src,
+compose_format_str (char *buf, size_t buflen, size_t col, int cols, char op, const char *src,
 		   const char *prefix, const char *ifstring,
 		   const char *elsestring,
 		   unsigned long data, format_flag flags)
 {
   char fmt[SHORT_STRING], tmp[SHORT_STRING];
-  int optional = (flags & M_FORMAT_OPTIONAL);
+  int optional = (flags & MUTT_FORMAT_OPTIONAL);
   MUTTMENU *menu = (MUTTMENU *) data;
 
   *buf = 0;
@@ -460,17 +462,17 @@ compose_format_str (char *buf, size_t buflen, size_t col, char op, const char *s
   }
 
   if (optional)
-    compose_status_line (buf, buflen, col, menu, ifstring);
-  else if (flags & M_FORMAT_OPTIONAL)
-    compose_status_line (buf, buflen, col, menu, elsestring);
+    compose_status_line (buf, buflen, col, cols, menu, ifstring);
+  else if (flags & MUTT_FORMAT_OPTIONAL)
+    compose_status_line (buf, buflen, col, cols, menu, elsestring);
 
   return (src);
 }
 
-static void compose_status_line (char *buf, size_t buflen, size_t col, MUTTMENU *menu, 
-      const char *p)
+static void compose_status_line (char *buf, size_t buflen, size_t col, int cols,
+                                 MUTTMENU *menu, const char *p)
 {
-  mutt_FormatString (buf, buflen, col, p, compose_format_str, 
+  mutt_FormatString (buf, buflen, col, cols, p, compose_format_str, 
         (unsigned long) menu, 0);
 }
 
@@ -482,9 +484,10 @@ static void compose_status_line (char *buf, size_t buflen, size_t col, MUTTMENU
  * -1	abort message
  */
 int mutt_compose_menu (HEADER *msg,   /* structure for new message */
-		    char *fcc,     /* where to save a copy of the message */
-		    size_t fcclen,
-		    HEADER *cur)   /* current message */
+                       char *fcc,     /* where to save a copy of the message */
+                       size_t fcclen,
+                       HEADER *cur,   /* current message */
+                       int flags)
 {
   char helpstr[LONG_STRING];
   char buf[LONG_STRING];
@@ -513,7 +516,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
   menu->tag = mutt_tag_attach;
   menu->data = idx;
   menu->help = mutt_compile_help (helpstr, sizeof (helpstr), MENU_COMPOSE, ComposeHelp);
-  
+
   while (loop)
   {
     switch (op = mutt_menuLoop (menu))
@@ -521,11 +524,11 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
       case OP_REDRAW:
 	draw_envelope (msg, fcc);
 	menu->offset = HDR_ATTACH;
-	menu->pagelen = LINES - HDR_ATTACH - 2;
+	menu->pagelen = MuttIndexWindow->rows - HDR_ATTACH;
 	break;
       case OP_COMPOSE_EDIT_FROM:
 	menu->redraw = edit_address_list (HDR_FROM, &msg->env->from);
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
 	break;
       case OP_COMPOSE_EDIT_TO:
 	menu->redraw = edit_address_list (HDR_TO, &msg->env->to);
@@ -534,7 +537,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  crypt_opportunistic_encrypt (msg);
 	  redraw_crypt_lines (msg);
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
       case OP_COMPOSE_EDIT_BCC:
 	menu->redraw = edit_address_list (HDR_BCC, &msg->env->bcc);
@@ -543,7 +546,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  crypt_opportunistic_encrypt (msg);
 	  redraw_crypt_lines (msg);
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
 	break;
       case OP_COMPOSE_EDIT_CC:
 	menu->redraw = edit_address_list (HDR_CC, &msg->env->cc);
@@ -552,7 +555,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  crypt_opportunistic_encrypt (msg);
 	  redraw_crypt_lines (msg);
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);	
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);	
         break;
       case OP_COMPOSE_EDIT_SUBJECT:
 	if (msg->env->subject)
@@ -562,30 +565,30 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	if (mutt_get_field ("Subject: ", buf, sizeof (buf), 0) == 0)
 	{
 	  mutt_str_replace (&msg->env->subject, buf);
-	  move (HDR_SUBJECT, HDR_XOFFSET);
+	  mutt_window_move (MuttIndexWindow, HDR_SUBJECT, HDR_XOFFSET);
 	  if (msg->env->subject)
 	    mutt_paddstr (W, msg->env->subject);
 	  else
-	    clrtoeol();
+	    mutt_window_clrtoeol(MuttIndexWindow);
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
       case OP_COMPOSE_EDIT_REPLY_TO:
 	menu->redraw = edit_address_list (HDR_REPLYTO, &msg->env->reply_to);
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
 	break;
       case OP_COMPOSE_EDIT_FCC:
 	strfcpy (buf, fcc, sizeof (buf));
-	if (mutt_get_field ("Fcc: ", buf, sizeof (buf), M_FILE | M_CLEAR) == 0)
+	if (mutt_get_field ("Fcc: ", buf, sizeof (buf), MUTT_FILE | MUTT_CLEAR) == 0)
 	{
 	  strfcpy (fcc, buf, fcclen);
 	  mutt_pretty_mailbox (fcc, fcclen);
-	  move (HDR_FCC, HDR_XOFFSET);
+	  mutt_window_move (MuttIndexWindow, HDR_FCC, HDR_XOFFSET);
 	  mutt_paddstr (W, fcc);
 	  fccSet = 1;
 	}
 	MAYBE_REDRAW (menu->redraw);
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
       case OP_COMPOSE_EDIT_MESSAGE:
 	if (Editor && (mutt_strcmp ("builtin", Editor) != 0) && !option (OPTEDITHDRS))
@@ -593,7 +596,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  mutt_edit_file (Editor, msg->content->filename);
 	  mutt_update_encoding (msg->content);
 	  menu->redraw = REDRAW_FULL;
-	  mutt_message_hook (NULL, msg, M_SEND2HOOK);
+	  mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
 	  break;
 	}
 	/* fall through */
@@ -606,7 +609,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  mutt_env_to_local (msg->env);
 	  mutt_edit_headers (NONULL (Editor), msg->content->filename, msg,
 			     fcc, fcclen);
-	  if (mutt_env_to_idna (msg->env, &tag, &err))
+	  if (mutt_env_to_intl (msg->env, &tag, &err))
 	  {
 	    mutt_error (_("Bad IDN in \"%s\": '%s'"), tag, err);
 	    FREE (&err);
@@ -628,7 +631,10 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	if (idxlen && idx[idxlen - 1]->content->next)
 	{
 	  for (i = 0; i < idxlen; i++)
+          {
+            FREE (&idx[i]->tree);
 	    FREE (&idx[i]);
+          }
 	  idxlen = 0;
 	  idx = mutt_gen_attach_list (msg->content, -1, idx, &idxlen, &idxmax, 0, 1);
 	  menu->data = idx;
@@ -636,7 +642,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	}
 
         menu->redraw = REDRAW_FULL;
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
 	break;
 
 
@@ -667,7 +673,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  unset_option(OPTNEEDREDRAW);
 	}
 	
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
 
@@ -715,7 +721,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 
 	  menu->redraw |= REDRAW_INDEX | REDRAW_STATUS;
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
       case OP_COMPOSE_ATTACH_MESSAGE:
@@ -751,10 +757,10 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 
 	  menu->redraw = REDRAW_FULL;
 
-	  ctx = mx_open_mailbox (fname, M_READONLY, NULL);
+	  ctx = mx_open_mailbox (fname, MUTT_READONLY, NULL);
 	  if (ctx == NULL)
 	  {
-	    mutt_perror (fname);
+	    mutt_error (_("Unable to open mailbox %s"), fname);
 	    break;
 	  }
 
@@ -822,7 +828,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  Sort = oldSort;
 	  SortAux = oldSortAux;
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
       case OP_DELETE:
@@ -844,7 +850,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  msg->content = idx[0]->content;
 
         menu->redraw |= REDRAW_STATUS;
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
 #define CURRENT idx[menu->current]->content
@@ -863,7 +869,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
         else
 	  mutt_message (_("The current attachment will be converted."));
 	menu->redraw = REDRAW_CURRENT;
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
       }
 #undef CURRENT
@@ -880,7 +886,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  mutt_str_replace (&idx[menu->current]->content->description, buf);
 	  menu->redraw = REDRAW_CURRENT;
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
       case OP_COMPOSE_UPDATE_ENCODING:
@@ -900,7 +906,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
           mutt_update_encoding(idx[menu->current]->content);
 	  menu->redraw = REDRAW_CURRENT | REDRAW_STATUS;
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
       
       case OP_COMPOSE_TOGGLE_DISPOSITION:
@@ -919,7 +925,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 
 	  menu->redraw = REDRAW_CURRENT;
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
       case OP_COMPOSE_EDIT_ENCODING:
@@ -938,7 +944,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  else
 	    mutt_error _("Invalid encoding.");
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
       case OP_COMPOSE_SEND_MESSAGE:
@@ -964,7 +970,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  if ((i = query_quadoption (OPT_COPY,
 				_("Save a copy of this message?"))) == -1)
 	    break;
-	  else if (i == M_NO)
+	  else if (i == MUTT_NO)
 	    *fcc = 0;
 	}
 
@@ -977,7 +983,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	mutt_edit_file (NONULL(Editor), idx[menu->current]->content->filename);
 	mutt_update_encoding (idx[menu->current]->content);
 	menu->redraw = REDRAW_CURRENT | REDRAW_STATUS;
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
 	break;
 
       case OP_COMPOSE_TOGGLE_UNLINK:
@@ -1018,11 +1024,13 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	CHECK_COUNT;
 	strfcpy (fname, idx[menu->current]->content->filename, sizeof (fname));
 	mutt_pretty_mailbox (fname, sizeof (fname));
-	if (mutt_get_field (_("Rename to: "), fname, sizeof (fname), M_FILE)
+	if (mutt_get_field (_("Rename to: "), fname, sizeof (fname), MUTT_FILE)
 							== 0 && fname[0])
 	{
 	  if (stat(idx[menu->current]->content->filename, &st) == -1)
 	  {
+            /* L10N:
+               "stat" is a system call. Do "man 2 stat" for more information. */
 	    mutt_error (_("Can't stat %s: %s"), fname, strerror (errno));
 	    break;
 	  }
@@ -1038,7 +1046,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	    mutt_stamp_attachment(idx[menu->current]->content);
 	  
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
       case OP_COMPOSE_NEW_MIME:
@@ -1048,9 +1056,9 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  int itype;
 	  FILE *fp;
 
-	  CLEARLINE (LINES-1);
+          mutt_window_clearline (MuttMessageWindow, 0);
 	  fname[0] = 0;
-	  if (mutt_get_field (_("New file: "), fname, sizeof (fname), M_FILE)
+	  if (mutt_get_field (_("New file: "), fname, sizeof (fname), MUTT_FILE)
 	      != 0 || !fname[0])
 	    continue;
 	  mutt_expand_path (fname, sizeof (fname));
@@ -1106,7 +1114,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	    menu->redraw = REDRAW_FULL;
 	  }
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);    
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);    
         break;
 
       case OP_COMPOSE_EDIT_MIME:
@@ -1116,7 +1124,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  mutt_update_encoding (idx[menu->current]->content);
 	  menu->redraw = REDRAW_FULL;
 	}
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
       case OP_VIEW_ATTACH:
@@ -1147,26 +1155,31 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	if (op == OP_FILTER) /* cte might have changed */
 	  menu->redraw = menu->tagprefix ? REDRAW_FULL : REDRAW_CURRENT;
         menu->redraw |= REDRAW_STATUS;
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
 	break;
 
       case OP_EXIT:
-	if ((i = query_quadoption (OPT_POSTPONE, _("Postpone this message?"))) == M_NO)
+	if ((i = query_quadoption (OPT_POSTPONE, _("Postpone this message?"))) == MUTT_NO)
 	{
-	  while (idxlen-- > 0)
-	  {
-	    /* avoid freeing other attachments */
-	    idx[idxlen]->content->next = NULL;
-	    idx[idxlen]->content->parts = NULL;
-            if (idx[idxlen]->unowned)
-              idx[idxlen]->content->unlink = 0;
-	    mutt_free_body (&idx[idxlen]->content);
-	    FREE (&idx[idxlen]->tree);
-	    FREE (&idx[idxlen]);
-	  }
-	  FREE (&idx);
-	  idxlen = 0;
-	  idxmax = 0;
+          for (i = 0; i < idxlen; i++)
+            if (idx[i]->unowned)
+              idx[i]->content->unlink = 0;
+
+          if (!(flags & MUTT_COMPOSE_NOFREEHEADER))
+          {
+            while (idxlen-- > 0)
+            {
+              /* avoid freeing other attachments */
+              idx[idxlen]->content->next = NULL;
+              idx[idxlen]->content->parts = NULL;
+              mutt_free_body (&idx[idxlen]->content);
+              FREE (&idx[idxlen]->tree);
+              FREE (&idx[idxlen]);
+            }
+            FREE (&idx);
+            idxlen = 0;
+            idxmax = 0;
+          }
 	  r = -1;
 	  loop = 0;
 	  break;
@@ -1234,18 +1247,24 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	if ((WithCrypto & APPLICATION_SMIME)
             && (msg->security & APPLICATION_SMIME))
 	{
-	  if (mutt_yesorno (_("S/MIME already selected. Clear & continue ? "),
-			     M_YES) != M_YES)
-	  {
-	    mutt_clear_error ();
-	    break;
-	  }
+          if (msg->security & (ENCRYPT | SIGN))
+          {
+            if (mutt_yesorno (_("S/MIME already selected. Clear & continue ? "),
+                              MUTT_YES) != MUTT_YES)
+            {
+              mutt_clear_error ();
+              break;
+            }
+            msg->security &= ~(ENCRYPT | SIGN);
+          }
 	  msg->security &= ~APPLICATION_SMIME;
 	  msg->security |= APPLICATION_PGP;
+          crypt_opportunistic_encrypt (msg);
+          redraw_crypt_lines (msg);
 	}
 	msg->security = crypt_pgp_send_menu (msg, &menu->redraw);
 	redraw_crypt_lines (msg);
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
 
@@ -1261,18 +1280,24 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	if ((WithCrypto & APPLICATION_PGP)
             && (msg->security & APPLICATION_PGP))
 	{
-	  if (mutt_yesorno (_("PGP already selected. Clear & continue ? "),
-			      M_YES) != M_YES)
-	  {
-	     mutt_clear_error ();
-	     break;
-	  }
+          if (msg->security & (ENCRYPT | SIGN))
+          {
+            if (mutt_yesorno (_("PGP already selected. Clear & continue ? "),
+                                MUTT_YES) != MUTT_YES)
+            {
+              mutt_clear_error ();
+              break;
+            }
+            msg->security &= ~(ENCRYPT | SIGN);
+          }
 	  msg->security &= ~APPLICATION_PGP;
 	  msg->security |= APPLICATION_SMIME;
+          crypt_opportunistic_encrypt (msg);
+          redraw_crypt_lines (msg);
 	}
 	msg->security = crypt_smime_send_menu(msg, &menu->redraw);
 	redraw_crypt_lines (msg);
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 
 
@@ -1280,7 +1305,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
       case OP_COMPOSE_MIX:
       
       	mix_make_chain (&msg->chain, &menu->redraw);
-        mutt_message_hook (NULL, msg, M_SEND2HOOK);
+        mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
         break;
 #endif
 
@@ -1289,10 +1314,10 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
     /* Draw formatted compose status line */
     if (menu->redraw & REDRAW_STATUS) 
     {
-	compose_status_line (buf, sizeof (buf), 0, menu, NONULL(ComposeFormat));
-	move(option (OPTSTATUSONTOP) ? 0 : LINES-2, 0);
+        compose_status_line (buf, sizeof (buf), 0, MuttStatusWindow->cols, menu, NONULL(ComposeFormat));
+	mutt_window_move (MuttStatusWindow, 0, 0);
 	SETCOLOR (MT_COLOR_STATUS);
-	mutt_paddstr (COLS, buf);
+	mutt_paddstr (MuttStatusWindow->cols, buf);
 	NORMAL_COLOR;
 	menu->redraw &= ~REDRAW_STATUS;
     }
@@ -1306,6 +1331,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
     for (i = 0; i < idxlen; i++)
     {
       idx[i]->content->aptr = NULL;
+      FREE (&idx[i]->tree);
       FREE (&idx[i]);
     }
   }
