@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */ 
 
 #if HAVE_CONFIG_H
@@ -63,28 +63,36 @@ time_t mutt_local_tz (time_t t)
   return (compute_tz (t, &utc));
 }
 
+/* theoretically time_t can be float but it is integer on most (if not all) systems */
+#define TIME_T_MAX ((((time_t) 1 << (sizeof(time_t) * 8 - 2)) - 1) * 2 + 1)
+#define TM_YEAR_MAX (1970 + (((((TIME_T_MAX - 59) / 60) - 59) / 60) - 23) / 24 / 366)
+
 /* converts struct tm to time_t, but does not take the local timezone into
    account unless ``local'' is nonzero */
 time_t mutt_mktime (struct tm *t, int local)
 {
   time_t g;
 
-  static int AccumDaysPerMonth[12] = {
+  static const int AccumDaysPerMonth[12] = {
     0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334
   };
 
+  /* Prevent an integer overflow */
+  if (t->tm_year > TM_YEAR_MAX)
+    return TIME_T_MAX;
+
   /* Compute the number of days since January 1 in the same year */
   g = AccumDaysPerMonth [t->tm_mon % 12];
 
   /* The leap years are 1972 and every 4. year until 2096,
-   * but this algoritm will fail after year 2099 */
+   * but this algorithm will fail after year 2099 */
   g += t->tm_mday;
   if ((t->tm_year % 4) || t->tm_mon < 2)
     g--;
   t->tm_yday = g;
 
   /* Compute the number of days since January 1, 1970 */
-  g += (t->tm_year - 70) * 365;
+  g += (t->tm_year - 70) * (time_t)365;
   g += (t->tm_year - 69) / 4;
 
   /* Compute the number of hours */
@@ -118,7 +126,7 @@ static int isLeapYearFeb (struct tm *tm)
 
 void mutt_normalize_time (struct tm *tm)
 {
-  static char DaysPerMonth[12] = {
+  static const char DaysPerMonth[12] = {
     31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
   };
   int nLeap;
