@@ -482,10 +482,10 @@ static void pretty_default (char *t, size_t l, const char *s, int type)
   {
     case DT_QUAD:
     {    
-      if (!strcasecmp (s, "M_YES")) strncpy (t, "yes", l);
-      else if (!strcasecmp (s, "M_NO")) strncpy (t, "no", l);
-      else if (!strcasecmp (s, "M_ASKYES")) strncpy (t, "ask-yes", l);
-      else if (!strcasecmp (s, "M_ASKNO")) strncpy (t, "ask-no", l);
+      if (!strcasecmp (s, "MUTT_YES")) strncpy (t, "yes", l);
+      else if (!strcasecmp (s, "MUTT_NO")) strncpy (t, "no", l);
+      else if (!strcasecmp (s, "MUTT_ASKYES")) strncpy (t, "ask-yes", l);
+      else if (!strcasecmp (s, "MUTT_ASKNO")) strncpy (t, "ask-no", l);
       break;
     }
     case DT_BOOL:
@@ -499,6 +499,9 @@ static void pretty_default (char *t, size_t l, const char *s, int type)
     case DT_SORT:
     {
       /* heuristic! */
+      if (strncmp (s, "SORT_", 5))
+        fprintf (stderr,
+                 "WARNING: expected prefix of SORT_ for type DT_SORT instead of %s\n", s);
       strncpy (t, s + 5, l);
       for (; *t; t++) *t = tolower ((unsigned char) *t);
       break;
@@ -506,7 +509,10 @@ static void pretty_default (char *t, size_t l, const char *s, int type)
     case DT_MAGIC:
     {
       /* heuristic! */
-      strncpy (t, s + 2, l);
+      if (strncmp (s, "MUTT_", 5))
+        fprintf (stderr,
+                 "WARNING: expected prefix of MUTT_ for type DT_MAGIC instead of %s\n", s);
+      strncpy (t, s + 5, l);
       for (; *t; t++) *t = tolower ((unsigned char) *t);
       break;
     }
