@@ -613,7 +613,7 @@ mutt_hcache_dump(header_cache_t *h, HEADER * header, int *off,
   *off = 0;
   d = lazy_malloc(sizeof (validate));
 
-  if (flags & M_GENERATE_UIDVALIDITY)
+  if (flags & MUTT_GENERATE_UIDVALIDITY)
   {
     struct timeval now;
     gettimeofday(&now, NULL);
@@ -775,7 +775,7 @@ mutt_hcache_fetch_raw (header_cache_t *h, const char *filename,
 /*
  * flags
  *
- * M_GENERATE_UIDVALIDITY
+ * MUTT_GENERATE_UIDVALIDITY
  * ignore uidvalidity param and store gettimeofday() as the value
  */
 int
@@ -931,7 +931,10 @@ hcache_open_tc (struct header_cache* h, const char* path)
     return 0;
   else
   {
-    dprint(2, (debugfile, "tcbdbopen %s failed: %s\n", path, errno));
+#ifdef DEBUG
+    int ecode = tcbdbecode (h->db);
+    dprint (2, (debugfile, "tcbdbopen failed for %s: %s (ecode %d)\n", path, tcbdberrmsg (ecode), ecode));
+#endif
     tcbdbdel(h->db);
     return -1;
   }
@@ -944,7 +947,12 @@ mutt_hcache_close(header_cache_t *h)
     return;
 
   if (!tcbdbclose(h->db))
-      dprint (2, (debugfile, "tcbdbclose failed for %s: %d\n", h->folder, errno));
+  {
+#ifdef DEBUG
+    int ecode = tcbdbecode (h->db);
+    dprint (2, (debugfile, "tcbdbclose failed for %s: %s (ecode %d)\n", h->folder, tcbdberrmsg (ecode), ecode));
+#endif
+  }
   tcbdbdel(h->db);
   FREE(&h->folder);
   FREE(&h);
