@@ -219,6 +219,8 @@ int mutt_user_is_recipient (HEADER *h)
  * %N = score
  * %O = like %L, except using address instead of name
  * %P = progress indicator for builtin pager
+ * %r = comma separated list of To: recipients
+ * %R = comma separated list of Cc: recipients
  * %s = subject
  * %S = short message status (e.g., N/O/D/!/r/-)
  * %t = `to:' field (recipients)
@@ -234,6 +236,7 @@ static const char *
 hdr_format_str (char *dest,
 		size_t destlen,
 		size_t col,
+                int cols,
 		char op,
 		const char *src,
 		const char *prefix,
@@ -247,9 +250,9 @@ hdr_format_str (char *dest,
   CONTEXT *ctx;
   char fmt[SHORT_STRING], buf2[LONG_STRING], ch, *p;
   int do_locales, i;
-  int optional = (flags & M_FORMAT_OPTIONAL);
+  int optional = (flags & MUTT_FORMAT_OPTIONAL);
   int threads = ((Sort & SORT_MASK) == SORT_THREADS);
-  int is_index = (flags & M_FORMAT_INDEX);
+  int is_index = (flags & MUTT_FORMAT_INDEX);
 #define THREAD_NEW (threads && hdr->collapsed && hdr->num_hidden > 1 && mutt_thread_contains_unread (ctx, hdr) == 1)
 #define THREAD_OLD (threads && hdr->collapsed && hdr->num_hidden > 1 && mutt_thread_contains_unread (ctx, hdr) == 2)
   size_t len;
@@ -548,11 +551,27 @@ hdr_format_str (char *dest,
       strfcpy(dest, NONULL(hfi->pager_progress), destlen);
       break;
 
+    case 'r':
+      buf2[0] = 0;
+      rfc822_write_address(buf2, sizeof(buf2), hdr->env->to, 1);
+      if (optional && buf2[0] == '\0')
+        optional = 0;
+      mutt_format_s (dest, destlen, prefix, buf2);
+      break;
+
+    case 'R':
+      buf2[0] = 0;
+      rfc822_write_address(buf2, sizeof(buf2), hdr->env->cc, 1);
+      if (optional && buf2[0] == '\0')
+        optional = 0;
+      mutt_format_s (dest, destlen, prefix, buf2);
+      break;
+
     case 's':
       
-      if (flags & M_FORMAT_TREE && !hdr->collapsed)
+      if (flags & MUTT_FORMAT_TREE && !hdr->collapsed)
       {
-	if (flags & M_FORMAT_FORCESUBJ)
+	if (flags & MUTT_FORMAT_FORCESUBJ)
 	{
 	  mutt_format_s (dest, destlen, "", NONULL (hdr->env->subject));
 	  snprintf (buf2, sizeof (buf2), "%s%s", hdr->tree, dest);
@@ -686,11 +705,11 @@ hdr_format_str (char *dest,
       {
 	i = 1;	/* reduce reuse recycle */
 	htmp = NULL;
-	if (flags & M_FORMAT_TREE
+	if (flags & MUTT_FORMAT_TREE
 	    && (hdr->thread->prev && hdr->thread->prev->message
 		&& hdr->thread->prev->message->env->x_label))
 	  htmp = hdr->thread->prev->message;
-	else if (flags & M_FORMAT_TREE
+	else if (flags & MUTT_FORMAT_TREE
 		 && (hdr->thread->parent && hdr->thread->parent->message
 		     && hdr->thread->parent->message->env->x_label))
 	  htmp = hdr->thread->parent->message;
@@ -717,9 +736,9 @@ hdr_format_str (char *dest,
   }
 
   if (optional)
-    mutt_FormatString (dest, destlen, col, ifstring, hdr_format_str, (unsigned long) hfi, flags);
-  else if (flags & M_FORMAT_OPTIONAL)
-    mutt_FormatString (dest, destlen, col, elsestring, hdr_format_str, (unsigned long) hfi, flags);
+    mutt_FormatString (dest, destlen, col, cols, ifstring, hdr_format_str, (unsigned long) hfi, flags);
+  else if (flags & MUTT_FORMAT_OPTIONAL)
+    mutt_FormatString (dest, destlen, col, cols, elsestring, hdr_format_str, (unsigned long) hfi, flags);
 
   return (src);
 #undef THREAD_NEW
@@ -735,11 +754,11 @@ _mutt_make_string (char *dest, size_t destlen, const char *s, CONTEXT *ctx, HEAD
   hfi.ctx = ctx;
   hfi.pager_progress = 0;
 
-  mutt_FormatString (dest, destlen, 0, s, hdr_format_str, (unsigned long) &hfi, flags);
+  mutt_FormatString (dest, destlen, 0, MuttIndexWindow->cols, s, hdr_format_str, (unsigned long) &hfi, flags);
 }
 
 void
-mutt_make_string_info (char *dst, size_t dstlen, const char *s, struct hdr_format_info *hfi, format_flag flags)
+mutt_make_string_info (char *dst, size_t dstlen, int cols, const char *s, struct hdr_format_info *hfi, format_flag flags)
 {
-  mutt_FormatString (dst, dstlen, 0, s, hdr_format_str, (unsigned long) hfi, flags);
+  mutt_FormatString (dst, dstlen, 0, cols, s, hdr_format_str, (unsigned long) hfi, flags);
 }
