@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-9 Brandon Long <blong@fiction.net>
+ * Copyright (C) 1996-1999 Brandon Long <blong@fiction.net>
  * Copyright (C) 1999-2009 Brendan Cully <brendan@kublai.com>
  *
  *     This program is free software; you can redistribute it and/or modify
@@ -137,8 +137,10 @@ int imap_read_headers (IMAP_DATA* idata, int msgbegin, int msgend)
   }
   if (evalhc)
   {
+    /* L10N:
+       Comparing the cached data with the IMAP server's data */
     mutt_progress_init (&progress, _("Evaluating cache..."),
-			M_PROGRESS_MSG, ReadInc, msgend + 1);
+			MUTT_PROGRESS_MSG, ReadInc, msgend + 1);
 
     snprintf (buf, sizeof (buf),
       "UID FETCH 1:%u (UID FLAGS)", uidnext - 1);
@@ -228,7 +230,7 @@ int imap_read_headers (IMAP_DATA* idata, int msgbegin, int msgend)
 #endif /* USE_HCACHE */
 
   mutt_progress_init (&progress, _("Fetching message headers..."),
-		      M_PROGRESS_MSG, ReadInc, msgend + 1);
+		      MUTT_PROGRESS_MSG, ReadInc, msgend + 1);
 
   for (msgno = msgbegin; msgno <= msgend ; msgno++)
   {
@@ -352,8 +354,9 @@ int imap_read_headers (IMAP_DATA* idata, int msgbegin, int msgend)
     }
   }
 
-  if (maxuid && (status = imap_mboxcache_get (idata, idata->mailbox, 0)))
-  status->uidnext = maxuid + 1;
+  if (maxuid && (status = imap_mboxcache_get (idata, idata->mailbox, 0)) &&
+      (status->uidnext < maxuid + 1))
+    status->uidnext = maxuid + 1;
 
 #if USE_HCACHE
   mutt_hcache_store_raw (idata->hcache, "/UIDVALIDITY", &idata->uid_validity,
@@ -389,7 +392,7 @@ error_out_0:
   return retval;
 }
 
-int imap_fetch_message (MESSAGE *msg, CONTEXT *ctx, int msgno)
+int imap_fetch_message (CONTEXT *ctx, MESSAGE *msg, int msgno)
 {
   IMAP_DATA* idata;
   HEADER* h;
@@ -496,7 +499,7 @@ int imap_fetch_message (MESSAGE *msg, CONTEXT *ctx, int msgno)
 	    goto bail;
 	  }
 	  mutt_progress_init (&progressbar, _("Fetching message..."),
-			      M_PROGRESS_SIZE, NetInc, bytes);
+			      MUTT_PROGRESS_SIZE, NetInc, bytes);
 	  if (imap_read_literal (msg->fp, idata, bytes, &progressbar) < 0)
 	    goto bail;
 	  /* pick up trailing line */
@@ -557,7 +560,7 @@ int imap_fetch_message (MESSAGE *msg, CONTEXT *ctx, int msgno)
   if (read != h->read)
   {
     h->read = read;
-    mutt_set_flag (ctx, h, M_NEW, read);
+    mutt_set_flag (ctx, h, MUTT_NEW, read);
   }
 
   h->lines = 0;
@@ -593,6 +596,21 @@ bail:
   return -1;
 }
 
+int imap_close_message (CONTEXT *ctx, MESSAGE *msg)
+{
+  return safe_fclose (&msg->fp);
+}
+
+int imap_commit_message (CONTEXT *ctx, MESSAGE *msg)
+{
+  int r = safe_fclose (&msg->fp);
+
+  if (r)
+    return r;
+
+  return imap_append_message (ctx, msg);
+}
+
 int imap_append_message (CONTEXT *ctx, MESSAGE *msg)
 {
   IMAP_DATA* idata;
@@ -640,9 +658,9 @@ int imap_append_message (CONTEXT *ctx, MESSAGE *msg)
   rewind (fp);
 
   mutt_progress_init (&progressbar, _("Uploading message..."),
-		      M_PROGRESS_SIZE, NetInc, len);
+		      MUTT_PROGRESS_SIZE, NetInc, len);
 
-  imap_munge_mbox_name (mbox, sizeof (mbox), mailbox);
+  imap_munge_mbox_name (idata, mbox, sizeof (mbox), mailbox);
   imap_make_date (internaldate, msg->received);
 
   imap_flags[0] = imap_flags[1] = 0;
@@ -745,7 +763,7 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
   int rc;
   int n;
   IMAP_MBOX mx;
-  int err_continue = M_NO;
+  int err_continue = MUTT_NO;
   int triedcreate = 0;
 
   idata = (IMAP_DATA*) ctx->data;
@@ -773,7 +791,7 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
   imap_fix_path (idata, mx.mbox, mbox, sizeof (mbox));
   if (!*mbox)
     strfcpy (mbox, "INBOX", sizeof (mbox));
-  imap_munge_mbox_name (mmbox, sizeof (mmbox), mbox);
+  imap_munge_mbox_name (idata, mmbox, sizeof (mmbox), mbox);
 
   /* loop in case of TRYCREATE */
   do
@@ -807,7 +825,7 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
         }
       }
 
-      rc = imap_exec_msgset (idata, "UID COPY", mmbox, M_TAG, 0, 0);
+      rc = imap_exec_msgset (idata, "UID COPY", mmbox, MUTT_TAG, 0, 0);
       if (!rc)
       {
         dprint (1, (debugfile, "imap_copy_messages: No messages tagged\n"));
@@ -883,16 +901,18 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
       {
         if (ctx->hdrs[n]->tagged)
         {
-          mutt_set_flag (ctx, ctx->hdrs[n], M_DELETE, 1);
+          mutt_set_flag (ctx, ctx->hdrs[n], MUTT_DELETE, 1);
+          mutt_set_flag (ctx, ctx->hdrs[n], MUTT_PURGE, 1);
           if (option (OPTDELETEUNTAG))
-            mutt_set_flag (ctx, ctx->hdrs[n], M_TAG, 0);
+            mutt_set_flag (ctx, ctx->hdrs[n], MUTT_TAG, 0);
         }
       }
     else
     {
-      mutt_set_flag (ctx, h, M_DELETE, 1);
+      mutt_set_flag (ctx, h, MUTT_DELETE, 1);
+      mutt_set_flag (ctx, h, MUTT_PURGE, 1);
       if (option (OPTDELETEUNTAG))
-        mutt_set_flag (ctx, h, M_TAG, 0);
+        mutt_set_flag (ctx, h, MUTT_TAG, 0);
     }
   }
 
@@ -1057,12 +1077,12 @@ char* imap_set_flags (IMAP_DATA* idata, HEADER* h, char* s)
   readonly = ctx->readonly;
   ctx->readonly = 0;
 
-  mutt_set_flag (ctx, h, M_NEW, !(hd->read || hd->old));
-  mutt_set_flag (ctx, h, M_OLD, hd->old);
-  mutt_set_flag (ctx, h, M_READ, hd->read);
-  mutt_set_flag (ctx, h, M_DELETE, hd->deleted);
-  mutt_set_flag (ctx, h, M_FLAG, hd->flagged);
-  mutt_set_flag (ctx, h, M_REPLIED, hd->replied);
+  mutt_set_flag (ctx, h, MUTT_NEW, !(hd->read || hd->old));
+  mutt_set_flag (ctx, h, MUTT_OLD, hd->old);
+  mutt_set_flag (ctx, h, MUTT_READ, hd->read);
+  mutt_set_flag (ctx, h, MUTT_DELETE, hd->deleted);
+  mutt_set_flag (ctx, h, MUTT_FLAG, hd->flagged);
+  mutt_set_flag (ctx, h, MUTT_REPLIED, hd->replied);
 
   /* this message is now definitively *not* changed (mutt_set_flag
    * marks things changed as a side-effect) */
