@@ -79,7 +79,7 @@ static struct mapping_t KeyNames[] = {
 #ifdef KEY_ENTER
   { "<Enter>",	KEY_ENTER },
 #endif
-  { "<Return>",	M_ENTER_C },
+  { "<Return>",	MUTT_ENTER_C },
   { "<Esc>",	'\033' },
   { "<Tab>",	'\t' },
   { "<Space>",	' ' },
@@ -863,7 +863,7 @@ int mutt_parse_push (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 {
   int r = 0;
 
-  mutt_extract_token (buf, s, M_TOKEN_CONDENSE);
+  mutt_extract_token (buf, s, MUTT_TOKEN_CONDENSE);
   if (MoreArgs (s))
   {
     strfcpy (err->data, _("push: too many arguments"), err->dsize);
@@ -1041,7 +1041,7 @@ int mutt_parse_macro (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
   if ((key = parse_keymap (menu, s, sizeof (menu) / sizeof (menu[0]), &nummenus, err)) == NULL)
     return (-1);
 
-  mutt_extract_token (buf, s, M_TOKEN_CONDENSE);
+  mutt_extract_token (buf, s, MUTT_TOKEN_CONDENSE);
   /* make sure the macro sequence is not an empty string */
   if (!*buf->data)
   {
@@ -1052,7 +1052,7 @@ int mutt_parse_macro (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
     if (MoreArgs (s))
     {
       seq = safe_strdup (buf->data);
-      mutt_extract_token (buf, s, M_TOKEN_CONDENSE);
+      mutt_extract_token (buf, s, MUTT_TOKEN_CONDENSE);
 
       if (MoreArgs (s))
       {
@@ -1133,7 +1133,7 @@ void mutt_what_key (void)
 {
   int ch;
 
-  mvprintw(LINES-1,0, _("Enter keys (^G to abort): "));
+  mutt_window_mvprintw (MuttMessageWindow, 0, 0, _("Enter keys (^G to abort): "));
   do {
     ch = getch();
     if (ch != ERR && ch != ctrl ('G'))
