@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-2000,2007 Michael R. Elkins <me@mutt.org>
- * Copyright (C) 1999-2004,2006-7 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 1996-2000,2007,2010 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1999-2004,2006-2007 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -761,12 +761,12 @@ char *mutt_read_line (char *s, size_t *size, FILE *fp, int *line, int flags)
     {
       if (line)
 	(*line)++;
-      if (flags & M_EOL)
+      if (flags & MUTT_EOL)
 	return s;
       *ch = 0;
       if (ch > s && *(ch - 1) == '\r')
 	*--ch = 0;
-      if (!(flags & M_CONT) || ch == s || *(ch - 1) != '\\')
+      if (!(flags & MUTT_CONT) || ch == s || *(ch - 1) != '\\')
 	return s;
       offset = ch - s - 1;
     }
