@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2002 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1996-2002,2012-2013 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1999-2002,2004 Thomas Roessler <roessler@does-not-exist.org>
  *
  *     This program is free software; you can redistribute it and/or modify
@@ -129,7 +129,7 @@ int mutt_num_postponed (int force)
 
     if (access (Postponed, R_OK | F_OK) != 0)
       return (PostCount = 0);
-    if (mx_open_mailbox (Postponed, M_NOSORT | M_QUIET, &ctx) == NULL)
+    if (mx_open_mailbox (Postponed, MUTT_NOSORT | MUTT_QUIET, &ctx) == NULL)
       PostCount = 0;
     else
       PostCount = ctx.msgcount;
@@ -149,7 +149,7 @@ static void post_entry (char *s, size_t slen, MUTTMENU *menu, int entry)
   CONTEXT *ctx = (CONTEXT *) menu->data;
 
   _mutt_make_string (s, slen, NONULL (HdrFmt), ctx, ctx->hdrs[entry],
-		     M_FORMAT_ARROWCURSOR);
+		     MUTT_FORMAT_ARROWCURSOR);
 }
 
 static HEADER *select_msg (void)
@@ -178,7 +178,8 @@ static HEADER *select_msg (void)
     {
       case OP_DELETE:
       case OP_UNDELETE:
-	mutt_set_flag (PostContext, PostContext->hdrs[menu->current], M_DELETE, (i == OP_DELETE) ? 1 : 0);
+        /* should deleted draft messages be saved in the trash folder? */
+	mutt_set_flag (PostContext, PostContext->hdrs[menu->current], MUTT_DELETE, (i == OP_DELETE) ? 1 : 0);
 	PostCount = PostContext->msgcount - PostContext->deleted;
 	if (option (OPTRESOLVE) && menu->current < menu->max - 1)
 	{
@@ -239,7 +240,7 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
   if (!Postponed)
     return (-1);
 
-  if ((PostContext = mx_open_mailbox (Postponed, M_NOSORT, NULL)) == NULL)
+  if ((PostContext = mx_open_mailbox (Postponed, MUTT_NOSORT, NULL)) == NULL)
   {
     PostCount = 0;
     mutt_error _("No postponed messages.");
@@ -275,14 +276,15 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
   }
 
   /* finished with this message, so delete it. */
-  mutt_set_flag (PostContext, h, M_DELETE, 1);
+  mutt_set_flag (PostContext, h, MUTT_DELETE, 1);
+  mutt_set_flag (PostContext, h, MUTT_PURGE, 1);
 
   /* update the count for the status display */
   PostCount = PostContext->msgcount - PostContext->deleted;
 
   /* avoid the "purge deleted messages" prompt */
   opt_delete = quadoption (OPT_DELETE);
-  set_quadoption (OPT_DELETE, M_YES);
+  set_quadoption (OPT_DELETE, MUTT_YES);
   mx_close_mailbox (PostContext, NULL);
   set_quadoption (OPT_DELETE, opt_delete);
 
@@ -541,9 +543,9 @@ int mutt_prepare_template (FILE *fp, CONTEXT *ctx, HEADER *newhdr, HEADER *hdr,
   char file[_POSIX_PATH_MAX];
   BODY *b;
   FILE *bfp;
-
   int rv = -1;
   STATE s;
+  int sec_type;
 
   memset (&s, 0, sizeof (s));
 
@@ -574,21 +576,19 @@ int mutt_prepare_template (FILE *fp, CONTEXT *ctx, HEADER *newhdr, HEADER *hdr,
 
   /* decrypt pgp/mime encoded messages */
 
-  if ((WithCrypto & (APPLICATION_PGP|APPLICATION_SMIME) & hdr->security)
-      && mutt_is_multipart_encrypted (newhdr->content))
+  if ((WithCrypto & APPLICATION_PGP) &&
+      (sec_type = mutt_is_multipart_encrypted (newhdr->content)))
   {
-    int ccap = WithCrypto & (APPLICATION_PGP|APPLICATION_SMIME) & hdr->security;
-    newhdr->security |= ENCRYPT | ccap;
-    if (!crypt_valid_passphrase (ccap))
+    newhdr->security |= sec_type;
+    if (!crypt_valid_passphrase (sec_type))
       goto err;
 
     mutt_message _("Decrypting message...");
-    if (((ccap & APPLICATION_PGP) && crypt_pgp_decrypt_mime (fp, &bfp, newhdr->content, &b) == -1)
-	|| ((ccap & APPLICATION_SMIME) && crypt_smime_decrypt_mime (fp, &bfp, newhdr->content, &b) == -1)
+    if ((crypt_pgp_decrypt_mime (fp, &bfp, newhdr->content, &b) == -1)
 	|| b == NULL)
     {
  err:
-      mx_close_message (&msg);
+      mx_close_message (ctx, &msg);
       mutt_free_envelope (&newhdr->env);
       mutt_free_body (&newhdr->content);
       mutt_error _("Decryption failed.");
@@ -666,7 +666,7 @@ int mutt_prepare_template (FILE *fp, CONTEXT *ctx, HEADER *newhdr, HEADER *hdr,
 	b->noconv = 1;
       else
       {
-	s.flags |= M_CHARCONV;
+	s.flags |= MUTT_CHARCONV;
 	b->noconv = 0;
       }
 
@@ -678,18 +678,26 @@ int mutt_prepare_template (FILE *fp, CONTEXT *ctx, HEADER *newhdr, HEADER *hdr,
       goto bail;
 
 
-    if ((WithCrypto & APPLICATION_PGP)
-	&& (mutt_is_application_pgp (b) & (ENCRYPT|SIGN)))
+    if ((WithCrypto & APPLICATION_PGP) &&
+	((sec_type = mutt_is_application_pgp (b)) & (ENCRYPT|SIGN)))
     {
-
       mutt_body_handler (b, &s);
 
-      newhdr->security |= mutt_is_application_pgp (newhdr->content);
+      newhdr->security |= sec_type;
 
       b->type = TYPETEXT;
       mutt_str_replace (&b->subtype, "plain");
       mutt_delete_parameter ("x-action", &b->parameter);
     }
+    else if ((WithCrypto & APPLICATION_SMIME) &&
+             ((sec_type = mutt_is_application_smime (b)) & (ENCRYPT|SIGN)))
+    {
+      mutt_body_handler (b, &s);
+
+      newhdr->security |= sec_type;
+      b->type = TYPETEXT;
+      mutt_str_replace (&b->subtype, "plain");
+    }
     else
       mutt_decode_attachment (b, &s);
 
@@ -729,7 +737,7 @@ int mutt_prepare_template (FILE *fp, CONTEXT *ctx, HEADER *newhdr, HEADER *hdr,
 
   /* that's it. */
   if (bfp != fp) safe_fclose (&bfp);
-  if (msg) mx_close_message (&msg);
+  if (msg) mx_close_message (ctx, &msg);
 
   if (rv == -1)
   {
