@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
- * Copyright (C) 2012 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2011-2013 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -202,7 +202,7 @@ next_token (const char *s, char *token, size_t *tokenlen, size_t tokenmax)
     return (parse_comment (s + 1, token, tokenlen, tokenmax));
   if (*s == '"')
     return (parse_quote (s + 1, token, tokenlen, tokenmax));
-  if (is_special (*s))
+  if (*s && is_special (*s))
   {
     if (*tokenlen < tokenmax)
       token[(*tokenlen)++] = *s;
@@ -229,6 +229,9 @@ parse_mailboxdomain (const char *s, const char *nonspecial,
   while (*s)
   {
     s = skip_email_wsp(s);
+    if (! *s)
+      return s;
+
     if (strchr (nonspecial, *s) == NULL && is_special (*s))
       return s;
 
@@ -798,8 +801,8 @@ ADDRESS *rfc822_cpy_adr_real (ADDRESS *addr)
   p->personal = safe_strdup (addr->personal);
   p->mailbox = safe_strdup (addr->mailbox);
   p->group = addr->group;
-  p->is_idn = addr->is_idn;
-  p->idn_checked = addr->idn_checked;
+  p->is_intl = addr->is_intl;
+  p->intl_checked = addr->intl_checked;
   return p;
 }
 
