@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001,2002 Oliver Ehli <elmy@acm.org>
+ * Copyright (C) 2001-2002 Oliver Ehli <elmy@acm.org>
  * Copyright (C) 2002 Mike Schiraldi <raldi@research.netsol.com>
  * Copyright (C) 2004 g10 Code GmbH
  *
@@ -56,6 +56,7 @@
 struct smime_command_context {
   const char *key;		    /* %k */
   const char *cryptalg;		    /* %a */
+  const char *digestalg;	    /* %d */
   const char *fname;		    /* %f */
   const char *sig_fname;	    /* %s */
   const char *certificates;	    /* %c */
@@ -158,6 +159,7 @@ int smime_valid_passphrase (void)
 static const char *_mutt_fmt_smime_command (char *dest,
 					    size_t destlen,
 					    size_t col,
+                                            int cols,
 					    char op,
 					    const char *src,
 					    const char *prefix,
@@ -168,7 +170,7 @@ static const char *_mutt_fmt_smime_command (char *dest,
 {
   char fmt[16];
   struct smime_command_context *cctx = (struct smime_command_context *) data;
-  int optional = (flags & M_FORMAT_OPTIONAL);
+  int optional = (flags & MUTT_FORMAT_OPTIONAL);
   
   switch (op)
   {
@@ -266,16 +268,27 @@ static const char *_mutt_fmt_smime_command (char *dest,
       break;
     }
     
+    case 'd':
+    {           /* algorithm for the signature message digest */
+      if (!optional) {
+	snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+	snprintf (dest, destlen, fmt, NONULL (cctx->digestalg));
+      }
+      else if (!cctx->key)
+	optional = 0;
+      break;
+    }
+
     default:
       *dest = '\0';
       break;
   }
 
   if (optional)
-    mutt_FormatString (dest, destlen, col, ifstring, _mutt_fmt_smime_command,
+    mutt_FormatString (dest, destlen, col, cols, ifstring, _mutt_fmt_smime_command,
 		       data, 0);
-  else if (flags & M_FORMAT_OPTIONAL)
-    mutt_FormatString (dest, destlen, col, elsestring, _mutt_fmt_smime_command,
+  else if (flags & MUTT_FORMAT_OPTIONAL)
+    mutt_FormatString (dest, destlen, col, cols, elsestring, _mutt_fmt_smime_command,
 		       data, 0);
 
   return (src);
@@ -286,7 +299,7 @@ static const char *_mutt_fmt_smime_command (char *dest,
 static void mutt_smime_command (char *d, size_t dlen,
 				struct smime_command_context *cctx, const char *fmt)
 {
-  mutt_FormatString (d, dlen, 0, NONULL(fmt), _mutt_fmt_smime_command,
+  mutt_FormatString (d, dlen, 0, MuttIndexWindow->cols, NONULL(fmt), _mutt_fmt_smime_command,
 		    (unsigned long) cctx, 0);
   dprint (2,(debugfile, "mutt_smime_command: %s\n", d));
 }
@@ -299,6 +312,7 @@ static pid_t smime_invoke (FILE **smimein, FILE **smimeout, FILE **smimeerr,
 			   const char *fname,
 			   const char *sig_fname,
 			   const char *cryptalg,
+			   const char *digestalg,
 			   const char *key,
 			   const char *certificates,
 			   const char *intermediates,
@@ -316,6 +330,7 @@ static pid_t smime_invoke (FILE **smimein, FILE **smimeout, FILE **smimeerr,
   cctx.sig_fname       = sig_fname;
   cctx.key	       = key;
   cctx.cryptalg	       = cryptalg;
+  cctx.digestalg       = digestalg;
   cctx.certificates    = certificates;
   cctx.intermediates   = intermediates;
   
@@ -462,7 +477,7 @@ static smime_key_t *smime_select_key (smime_key_t *keys, char *query)
           snprintf (buf, sizeof (buf), _("%s Do you really want to use the key?"),
                     _(s));
 
-          if (mutt_yesorno (buf, M_NO) != M_YES)
+          if (mutt_yesorno (buf, MUTT_NO) != MUTT_YES)
           {
             mutt_clear_error ();
             break;
@@ -495,7 +510,12 @@ static smime_key_t *smime_parse_key(char *buf)
 
   for (p = buf; p; p = pend)
   {
-    if ((pend = strchr (p, ' ')) || (pend = strchr (p, '\n')))
+    /* Some users manually maintain their .index file, and use a tab
+     * as a delimiter, which the old parsing code (using fscanf)
+     * happened to allow.  smime_keys.pl uses a space, so search for both.
+     */
+    if ((pend = strchr (p, ' ')) || (pend = strchr (p, '\t')) ||
+        (pend = strchr (p, '\n')))
       *pend++ = 0;
 
     /* For backward compatibility, don't count consecutive delimiters
@@ -746,7 +766,7 @@ smime_key_t *smime_ask_for_key(char *prompt, short abilities, short public)
   FOREVER
   {
     resp[0] = 0;
-    if (mutt_get_field (prompt, resp, sizeof (resp), M_CLEAR) != 0)
+    if (mutt_get_field (prompt, resp, sizeof (resp), MUTT_CLEAR) != 0)
       return NULL;
 
     if ((key = smime_get_key_by_str (resp, abilities, public)))
@@ -915,6 +935,7 @@ static int smime_handle_cert_email (char *certificate, char *mailbox,
   char email[STRING];
   int ret = -1, count = 0;
   pid_t thepid;
+  size_t len = 0;
 
   mutt_mktemp (tmpfname, sizeof (tmpfname));
   if ((fperr = safe_fopen (tmpfname, "w+")) == NULL)
@@ -935,7 +956,7 @@ static int smime_handle_cert_email (char *certificate, char *mailbox,
 
   if ((thepid =  smime_invoke (NULL, NULL, NULL,
 			       -1, fileno (fpout), fileno (fperr),
-			       certificate, NULL, NULL, NULL, NULL, NULL,
+			       certificate, NULL, NULL, NULL, NULL, NULL, NULL,
 			       SmimeGetCertEmailCommand))== -1)
   {
     mutt_message (_("Error: unable to create OpenSSL subprocess!"));
@@ -954,7 +975,9 @@ static int smime_handle_cert_email (char *certificate, char *mailbox,
 
   while ((fgets (email, sizeof (email), fpout)))
   {
-    *(email + mutt_strlen (email)-1) = '\0';
+    len = mutt_strlen (email);
+    if (len && (email[len - 1] == '\n'))
+      email[len - 1] = '\0';
     if(mutt_strncasecmp (email, mailbox, mutt_strlen (mailbox)) == 0)
       ret=1;
 
@@ -982,7 +1005,9 @@ static int smime_handle_cert_email (char *certificate, char *mailbox,
     rewind (fpout);
     while ((fgets (email, sizeof (email), fpout)))
     {
-      *(email + mutt_strlen (email) - 1) = '\0';
+      len = mutt_strlen (email);
+      if (len && (email[len - 1] == '\n'))
+        email[len - 1] = '\0';
       (*buffer)[count] = safe_calloc(1, mutt_strlen (email) + 1);
       strncpy((*buffer)[count], email, mutt_strlen (email));
       count++;
@@ -1028,7 +1053,7 @@ static char *smime_extract_certificate (char *infile)
   */
   if ((thepid =  smime_invoke (NULL, NULL, NULL,
 			       -1, fileno (fpout), fileno (fperr),
-			       infile, NULL, NULL, NULL, NULL, NULL,
+			       infile, NULL, NULL, NULL, NULL, NULL, NULL,
 			       SmimePk7outCommand))== -1)
   {
     mutt_any_key_to_continue (_("Error: unable to create OpenSSL subprocess!"));
@@ -1072,7 +1097,7 @@ static char *smime_extract_certificate (char *infile)
    */
   if ((thepid =  smime_invoke (NULL, NULL, NULL,
 			       -1, fileno (fpout), fileno (fperr),
-			       pk7out, NULL, NULL, NULL, NULL, NULL,
+			       pk7out, NULL, NULL, NULL, NULL, NULL, NULL,
 			       SmimeGetCertCommand))== -1)
   {
     mutt_any_key_to_continue (_("Error: unable to create OpenSSL subprocess!"));
@@ -1137,7 +1162,7 @@ static char *smime_extract_signer_certificate (char *infile)
    */
   if ((thepid =  smime_invoke (NULL, NULL, NULL,
 			       -1, -1, fileno (fperr),
-			       infile, NULL, NULL, NULL, certfile, NULL,
+			       infile, NULL, NULL, NULL, NULL, certfile, NULL,
 			       SmimeGetSignerCertCommand))== -1)
   {
     mutt_any_key_to_continue (_("Error: unable to create OpenSSL subprocess!"));
@@ -1212,7 +1237,7 @@ void smime_invoke_import (char *infile, char *mailbox)
   
     if ((thepid =  smime_invoke (&smimein, NULL, NULL,
 				 -1, fileno(fpout), fileno(fperr),
-				 certfile, NULL, NULL, NULL, NULL, NULL,
+				 certfile, NULL, NULL, NULL, NULL, NULL, NULL,
 				 SmimeImportCertCommand))== -1)
     {
       mutt_message (_("Error: unable to create OpenSSL subprocess!"));
@@ -1258,7 +1283,7 @@ int smime_verify_sender(HEADER *h)
 
   if(h->security & ENCRYPT)
     mutt_copy_message (fpout, Context, h,
-		       M_CM_DECODE_CRYPT & M_CM_DECODE_SMIME,
+		       MUTT_CM_DECODE_CRYPT & MUTT_CM_DECODE_SMIME,
 		       CH_MIME|CH_WEED|CH_NONEWLINE);
   else
     mutt_copy_message (fpout, Context, h, 0, 0);
@@ -1324,7 +1349,7 @@ pid_t smime_invoke_encrypt (FILE **smimein, FILE **smimeout, FILE **smimeerr,
 {
   return smime_invoke (smimein, smimeout, smimeerr,
 		       smimeinfd, smimeoutfd, smimeerrfd,
-		       fname, NULL, SmimeCryptAlg, NULL, uids, NULL,
+		       fname, NULL, SmimeCryptAlg, NULL, NULL, uids, NULL,
 		       SmimeEncryptCommand);
 }
 
@@ -1335,7 +1360,7 @@ pid_t smime_invoke_sign (FILE **smimein, FILE **smimeout, FILE **smimeerr,
 			 const char *fname)
 {
   return smime_invoke (smimein, smimeout, smimeerr, smimeinfd, smimeoutfd,
-		       smimeerrfd, fname, NULL, NULL, SmimeKeyToUse,
+		       smimeerrfd, fname, NULL, NULL, SmimeDigestAlg, SmimeKeyToUse,
 		       SmimeCertToUse, SmimeIntermediateToUse,
 		       SmimeSignCommand);
 }
@@ -1462,6 +1487,33 @@ BODY *smime_build_smime_entity (BODY *a, char *certlist)
 }
 
 
+/* The openssl -md doesn't want hyphens:
+ *   md5, sha1,  sha224,  sha256,  sha384,  sha512
+ * However, the micalg does:
+ *   md5, sha-1, sha-224, sha-256, sha-384, sha-512
+ */
+static char *openssl_md_to_smime_micalg(char *md)
+{
+  char *micalg;
+  size_t l;
+
+  if (!md)
+    return 0;
+
+  if (mutt_strncasecmp ("sha", md, 3) == 0)
+  {
+    l = strlen (md) + 2;
+    micalg = (char *)safe_malloc (l);
+    snprintf (micalg, l, "sha-%s", md +3);
+  }
+  else
+  {
+    micalg = safe_strdup (md);
+  }
+
+  return micalg;
+}
+
 
 
 BODY *smime_sign_message (BODY *a )
@@ -1475,6 +1527,7 @@ BODY *smime_sign_message (BODY *a )
   pid_t thepid;
   smime_key_t *default_key;
   char *intermediates;
+  char *micalg;
 
   if (!SmimeDefaultKey)
   {
@@ -1581,8 +1634,11 @@ BODY *smime_sign_message (BODY *a )
   t->disposition = DISPINLINE;
 
   mutt_generate_boundary (&t->parameter);
-  /* check if this can be extracted from private key somehow.... */
-  mutt_set_parameter ("micalg", "sha1", &t->parameter);
+
+  micalg = openssl_md_to_smime_micalg (SmimeDigestAlg);
+  mutt_set_parameter ("micalg", micalg, &t->parameter);
+  FREE (&micalg);
+
   mutt_set_parameter ("protocol", "application/x-pkcs7-signature",
 		     &t->parameter);
 
@@ -1624,7 +1680,7 @@ pid_t smime_invoke_verify (FILE **smimein, FILE **smimeout, FILE **smimeerr,
 			   const char *fname, const char *sig_fname, int opaque)
 {
   return smime_invoke (smimein, smimeout, smimeerr, smimeinfd, smimeoutfd,
-		       smimeerrfd, fname, sig_fname, NULL, NULL, NULL, NULL,
+		       smimeerrfd, fname, sig_fname, NULL, NULL, NULL, NULL, NULL,
 		       (opaque ? SmimeVerifyOpaqueCommand : SmimeVerifyCommand));
 }
 
@@ -1635,7 +1691,7 @@ pid_t smime_invoke_decrypt (FILE **smimein, FILE **smimeout, FILE **smimeerr,
 			    const char *fname)
 {
   return smime_invoke (smimein, smimeout, smimeerr, smimeinfd, smimeoutfd,
-		       smimeerrfd, fname, NULL, NULL, SmimeKeyToUse,
+		       smimeerrfd, fname, NULL, NULL, NULL, SmimeKeyToUse,
 		       SmimeCertToUse, NULL, SmimeDecryptCommand);
 }
 
@@ -1814,7 +1870,7 @@ static BODY *smime_handle_entity (BODY *m, STATE *s, FILE *outFile)
   {
     safe_fclose (&smimeout); smimeout = NULL;
     mutt_unlink (tmpfname);
-    if (s->flags & M_DISPLAY)
+    if (s->flags & MUTT_DISPLAY)
       state_attach_puts (_("[-- Error: unable to create OpenSSL subprocess! --]\n"), s);
     return NULL;
   }
@@ -1825,7 +1881,7 @@ static BODY *smime_handle_entity (BODY *m, STATE *s, FILE *outFile)
   {
     safe_fclose (&smimeout); smimeout = NULL;
     mutt_unlink (tmpfname);
-    if (s->flags & M_DISPLAY)
+    if (s->flags & MUTT_DISPLAY)
       state_attach_puts (_("[-- Error: unable to create OpenSSL subprocess! --]\n"), s);
     return NULL;
   }
@@ -1845,7 +1901,7 @@ static BODY *smime_handle_entity (BODY *m, STATE *s, FILE *outFile)
   mutt_unlink (tmpfname);
   
 
-  if (s->flags & M_DISPLAY)
+  if (s->flags & MUTT_DISPLAY)
   {
     fflush (smimeerr);
     rewind (smimeerr);
@@ -1924,7 +1980,7 @@ static BODY *smime_handle_entity (BODY *m, STATE *s, FILE *outFile)
     fpout = NULL;
   }
 
-  if (s->flags & M_DISPLAY)
+  if (s->flags & MUTT_DISPLAY)
   {
     if (type & ENCRYPT)
       state_attach_puts (_("\n[-- End of S/MIME encrypted data. --]\n"), s);
@@ -2052,6 +2108,10 @@ int smime_send_menu (HEADER *msg, int *redraw)
   if (option (OPTCRYPTOPPORTUNISTICENCRYPT) && (msg->security & OPPENCRYPT))
   {
     prompt = _("S/MIME (s)ign, encrypt (w)ith, sign (a)s, (c)lear, or (o)ppenc mode off? ");
+    /* L10N: The 'f' is from "forget it", an old undocumented synonym of
+       'clear'.  Please use a corresponding letter in your language.
+       Alternatively, you may duplicate the letter 'c' is translated to.
+       This comment also applies to the two following letter sequences. */
     letters = _("swafco");
     choices = "SwaFCo";
   }
