@@ -40,7 +40,7 @@ static char *get_sort_str (char *buf, size_t buflen, int method)
   return buf;
 }
 
-static void _menu_status_line (char *buf, size_t buflen, size_t col, MUTTMENU *menu, const char *p);
+static void _menu_status_line (char *buf, size_t buflen, size_t col, int cols, MUTTMENU *menu, const char *p);
 
 /* %b = number of incoming folders with unread messages [option]
  * %d = number of deleted messages [option]
@@ -62,13 +62,13 @@ static void _menu_status_line (char *buf, size_t buflen, size_t col, MUTTMENU *m
  * %v = Mutt version 
  * %V = currently active limit pattern [option] */
 static const char *
-status_format_str (char *buf, size_t buflen, size_t col, char op, const char *src,
+status_format_str (char *buf, size_t buflen, size_t col, int cols, char op, const char *src,
 		   const char *prefix, const char *ifstring,
 		   const char *elsestring,
 		   unsigned long data, format_flag flags)
 {
   char fmt[SHORT_STRING], tmp[SHORT_STRING], *cp;
-  int count, optional = (flags & M_FORMAT_OPTIONAL);
+  int count, optional = (flags & MUTT_FORMAT_OPTIONAL);
   MUTTMENU *menu = (MUTTMENU *) data;
 
   *buf = 0;
@@ -218,7 +218,7 @@ status_format_str (char *buf, size_t buflen, size_t col, char op, const char *sr
 	i = option(OPTATTACHMSG) ? 3 : ((Context->readonly ||
           Context->dontwrite) ? 2 : (Context->changed ||
           /* deleted doesn't necessarily mean changed in IMAP */
-          (Context->magic != M_IMAP &&
+          (Context->magic != MUTT_IMAP &&
            Context->deleted)) ? 1 : 0);
       }
       
@@ -290,19 +290,21 @@ status_format_str (char *buf, size_t buflen, size_t col, char op, const char *sr
   }
 
   if (optional)
-    _menu_status_line (buf, buflen, col, menu, ifstring);
-  else if (flags & M_FORMAT_OPTIONAL)
-    _menu_status_line (buf, buflen, col, menu, elsestring);
+    _menu_status_line (buf, buflen, col, cols, menu, ifstring);
+  else if (flags & MUTT_FORMAT_OPTIONAL)
+    _menu_status_line (buf, buflen, col, cols, menu, elsestring);
 
   return (src);
 }
 
-static void _menu_status_line (char *buf, size_t buflen, size_t col, MUTTMENU *menu, const char *p)
+static void _menu_status_line (char *buf, size_t buflen, size_t col, int cols, MUTTMENU *menu, const char *p)
 {
-  mutt_FormatString (buf, buflen, col, p, status_format_str, (unsigned long) menu, 0);
+  mutt_FormatString (buf, buflen, col, cols, p, status_format_str, (unsigned long) menu, 0);
 }
 
 void menu_status_line (char *buf, size_t buflen, MUTTMENU *menu, const char *p)
 {
-  mutt_FormatString (buf, buflen, 0, p, status_format_str, (unsigned long) menu, 0);
+  mutt_FormatString (buf, buflen, 0,
+                     menu ? menu->statuswin->cols : MuttStatusWindow->cols,
+                     p, status_format_str, (unsigned long) menu, 0);
 }
